
#ifndef TERMINAL_EXPORT_H
#define TERMINAL_EXPORT_H

#ifdef TERMINAL_STATIC_DEFINE
#  define TERMINAL_EXPORT
#  define TERMINAL_NO_EXPORT
#else
#  ifndef TERMINAL_EXPORT
#    ifdef MauiKitTerminal3_EXPORTS
        /* We are building this library */
#      define TERMINAL_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TERMINAL_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TERMINAL_NO_EXPORT
#    define TERMINAL_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TERMINAL_DEPRECATED
#  define TERMINAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TERMINAL_DEPRECATED_EXPORT
#  define TERMINAL_DEPRECATED_EXPORT TERMINAL_EXPORT TERMINAL_DEPRECATED
#endif

#ifndef TERMINAL_DEPRECATED_NO_EXPORT
#  define TERMINAL_DEPRECATED_NO_EXPORT TERMINAL_NO_EXPORT TERMINAL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TERMINAL_NO_DEPRECATED
#    define TERMINAL_NO_DEPRECATED
#  endif
#endif

#endif /* TERMINAL_EXPORT_H */
