// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef Terminal_VERSION_H
#define Terminal_VERSION_H

#define Terminal_VERSION_STRING "3.1.0"
#define Terminal_VERSION_MAJOR 3
#define Terminal_VERSION_MINOR 1
#define Terminal_VERSION_PATCH 0
#define Terminal_VERSION ((3<<16)|(1<<8)|(0))

#endif
